import TsconfigPathsPlugin from 'tsconfig-paths-webpack-plugin';
const disableCaching = String(process.env.BUILD_CACHE_DISABLED).toLowerCase() === 'true';
const cacheLoader = (cacheDirectory) => {
    return {
        loader: 'cache-loader',
        options: {
            cacheDirectory,
        },
    };
};
export function getTypeScriptWebpackRule(_plugins, resolvePlugins, options, buildTarget) {
    const configFile = (buildTarget === 'server'
        ? options.buildConfig.TS_CONFIG_SERVER
        : options.buildConfig.TS_CONFIG_CLIENT) || 'tsconfig.json';
    options.log.info(`Target ${buildTarget} using ts config file: ${configFile}`);
    const tsConfigPathsPluginConfig = {};
    const tsLoaderOptions = {
        compilerOptions: {
            noEmit: false,
        },
    };
    if (configFile) {
        tsConfigPathsPluginConfig.configFile = configFile;
        tsLoaderOptions.configFile = configFile;
    }
    resolvePlugins.push(new TsconfigPathsPlugin(tsConfigPathsPluginConfig));
    const tsLoader = {
        loader: 'ts-loader',
        options: tsLoaderOptions,
    };
    return {
        test: /\.tsx?$/,
        use: !disableCaching ? [cacheLoader(options.cacheDirectory), tsLoader] : [tsLoader],
    };
}
//# sourceMappingURL=ts-loader-config.js.map